const gateway = Gateway.create(public_key);
const threeDS = gateway.get3DSecure();
const queryString = window.location.search;
const urlParams = new URLSearchParams(queryString);
let threeDSecureInterface = null;

gateway.on('error', (e) => {
    show_form_error();
    create_error_log({
        details: e,
        type: e.type
    });
});

function request_auth(options) {
    try {
        // Ocultar el modal y mostrar el loader
        jQuery('#close-modal').hide();  // Asegurarse de ocultar el botón antes de empezar
        document.getElementsByTagName('authBox')[0].style.display = 'flex';
        document.getElementById('loader').style.display = 'block';

        // Verificar si la interfaz ya está montada y desmontarla si es necesario
        if (threeDSecureInterface && threeDSecureInterface.isMounted()) {
            threeDSecureInterface.unmount();
        }

        // Crear una nueva instancia del UI de 3DS
        threeDSecureInterface = threeDS.createUI(options);
        threeDSecureInterface.start('modal');

        // Manejo del evento 'challenge'
        threeDSecureInterface.on('challenge', function(e) {
            document.getElementById('loader').style.display = 'none';
            jQuery('#detail-content').hide();
        });

        // Manejo del evento 'complete'
        threeDSecureInterface.on('complete', function(e) {
            try {
                document.getElementById('loader').style.display = 'none';
                jQuery('#detail-content').show();
                threeDSecureInterface.unmount();

                // Verificación de los códigos de transacción
                if (e && e.code) {
                    if (e.code === 'TRANSACTION_STATUS_N' || e.code === 'TRANSACTION_STATUS_U' || e.code === 'TRANSACTION_STATUS_R') {
                        create_error_log({
                            details: e,
                            type: '3DSecure - Complete'
                        });
                        document.getElementById('response').innerHTML = _lang(e.code);
                        jQuery('#close-modal').show(); // Mostrar el botón solo si la transacción no es exitosa
                    }
                } else if (e.type === 'gatewayError') {
                    create_error_log({
                        details: e,
                        type: '3DSecure - Complete'
                    });
                    document.getElementById('response').innerHTML = _lang('gatewayError');
                    jQuery('#close-modal').show(); // Mostrar el botón en caso de error del gateway
                }

                // Verificar autenticación del titular de la tarjeta
                if (e && (e.cardHolderAuth === 'verified' || e.cardHolderAuth === 'attempted')) {
                    sendResponse({
                        ...options,
                        cavv: e.cavv,
                        xid: e.xid,
                        eci: e.eci,
                        cardHolderAuth: e.cardHolderAuth,
                        threeDsVersion: e.threeDsVersion,
                        directoryServerId: e.directoryServerId,
                        cardHolderInfo: e.cardHolderInfo,
                    }, 'verified');

                    document.getElementById('responseTitle').innerHTML = _lang('Success');
                    document.getElementById('response').innerHTML = _lang('Submitting Payment Request');
                    // NO mostrar el botón aquí, porque la transacción aún no ha terminado
                }

                // Manejar el caso de cardHolderAuth nulo
                if (e && e.cardHolderAuth == null) {
                    create_error_log({
                        details: e,
                        type: '3DSecure - Complete'
                    });
                    document.getElementById('response').innerHTML = _lang('NullcardHolderAuth');
                    jQuery('#close-modal').show(); // Mostrar el botón en caso de error
                }
            } catch (error) {
                console.error('Error en evento complete:', error);
                jQuery('#close-modal').show(); // Mostrar el botón en caso de error inesperado
            }
        });

        // Manejo del evento 'failure'
        threeDSecureInterface.on('failure', function(e) {
            console.log('3d failure', e);
            create_error_log({
                details: e,
                type: '3DSecure - failure'
            });
            jQuery('#detail-content').show();
            threeDSecureInterface.unmount();

            if (e && (e.code === 'TRANSACTION_STATUS_N' || e.code === 'TRANSACTION_STATUS_U' || e.code === 'TRANSACTION_STATUS_R')) {
                document.getElementById('response').innerHTML = _lang(e.code);
            }
            if (e && e.type === 'gatewayError') {
                document.getElementById('response').innerHTML = _lang(e.type);
            }
            jQuery('#close-modal').show(); // Mostrar el botón al finalizar con fallo
        });

        // Manejo del evento 'error'
        threeDSecureInterface.on('error', function(e) {
            console.log('3d Error', e);
            create_error_log({
                details: e,
                type: '3DSecure - error'
            });
            jQuery('#detail-content').show();
            threeDSecureInterface.unmount();
            document.getElementById('response').innerHTML = _lang('generalError');
            jQuery('#close-modal').show(); // Mostrar el botón al finalizar con error
        });

    } catch (err) {
        console.log(err);
        jQuery('#close-modal').show(); // Mostrar el botón en caso de excepción general
    }
}

// callback to react function
function sendResponse(data, type) {
    if (type == "verified") {
        precess_pay_now(data);
    }
}

function _lang(text) {
    let l = langu;
    let lang = JSON.parse(l);
    text = text.trim();
    if (!sys_lang) {
        return text;
    } else if (sys_lang == 'en') {
        if ((text in lang['en'])) {
            return lang['en'][text];
        } else {
            return text;
        }
    } else if (sys_lang == 'es') {
        if ((text in lang['es'])) {
            return lang['es'][text];
        } else {
            return text;
        }
    }
}
    
    const precess_pay_now = (values)=>{

        let cc = jQuery("#wolk_ccNo").val()
        let customer_ip = jQuery("#customer_ip").val()
        let wolk_first_name = jQuery("#wolk_first_name").val()
        let wolk_last_name = jQuery("#wolk_last_name").val()
        let wolk_email = jQuery("#wolk_email").val()
        let cardholder = jQuery("#wolk_cardholder").val()
        let wolk_month = jQuery("#wolk_month").val()
        let wolk_year = jQuery("#wolk_year").val()
        let wolk_cvc = jQuery("#wolk_cvc").val()
        cc = cc.replaceAll(' ','');
        var data = new FormData();
        let rawdata = {
            'action' : 'wolk_submit_payment_request',
            'security_key' : security_key,
            'type': 'sale',
            'amount': total,
            'ccnumber': cc,
            'ccexp': wolk_month+'/'+wolk_year,
            'cvv': wolk_cvc,
            'firstname' : wolk_first_name,
            'lastname' : wolk_last_name,
            'email' : wolk_email,
            'ipaddress' : customer_ip,
            currency: currency_code,
            country : country,
            // currency: "CRC",
            // country: 'CR',
            ...values,
            xid: values.xid == null ? null : values.xid
        };


        for (var key in rawdata) {
            data.append(key, rawdata[key])
        }
        data.append('nonce', ajax_var.nonce)

    var config = {
      method: 'POST',
      body : data
    };
    
    fetch(ajax_var.url,config)
    .then(response => response.text())
    .then(async function (response) {
      let res = await queryStringToJSON(response)
      if(res.response == 1){

        document.getElementById('responseTitle').innerHTML = _lang('Transaction Approved')
        //document.getElementById('response').innerHTML =  _lang(Transaction ID = jQuery{res.transactionid})

        setTimeout(()=>{
            var formData = new FormData();
            formData.append( 'action', 'wolk_complete_order' );
            formData.append( 'order_id', order_id );
            formData.append('nonce', ajax_var.nonce)
            fetch(ajax_var.url,
            {
                method: 'POST',
                body: formData,
            })
            .then( res => res.json() )
            .then( res => {
                if(res.result == "success"){
                    window.location = res.redirect;
                }
            })
            .catch( err => console.log( err ) );
        },1000)

      }else if(res.response == 2){
        create_error_log({
            details : res,
            type : 'Payment Proceed'
        })
       
        jQuery('#detail-content').show()
        threeDSecureInterface.unmount()
        jQuery('#close-modal').show();
        
        document.getElementById('responseTitle').innerHTML = 'Transaction Declined'
        document.getElementById('response').innerHTML =  _lang(res.response_code)
        

      }else if(res.response == 3){
        create_error_log({
            details : res,
            type : 'Payment Proceed'
        })
        jQuery('#detail-content').show()
        threeDSecureInterface.unmount()
        jQuery('#close-modal').show();
        document.getElementById('responseTitle').innerHTML = _lang('Error')
        document.getElementById('response').innerHTML =  _lang(res.response_code)
      }
      else{
        create_error_log({
            details : res,
            type : 'Payment Proceed'
        })
        jQuery('#detail-content').show()
        threeDSecureInterface.unmount()
        jQuery('#close-modal').show();

        document.getElementById('responseTitle').innerHTML = _lang('Error')
        document.getElementById('response').innerHTML =  _lang(res.response_code)
      }
    })
    .catch(function (error) {
      console.log(error);
    });
  }

  function queryStringToJSON(queryString) {
    if(queryString.indexOf('?') > -1){
      queryString = queryString.split('?')[1];
    }
    var pairs = queryString.split('&');
    var result = {};
    pairs.forEach(function(pair) {
      pair = pair.split('=');
      result[pair[0]] = decodeURIComponent(pair[1] || '');
    });
    return result;
  }


  function closeModal (){

  }

  function creditCardType(cc) {
    if (cc.substring(0, 2) == "34" || cc.substring(0, 2) == "37") {
      return "AMEX"
    }
    else{
      return "other"
    }
  }


  const create_error_log = (values)=>{
   
    let cc = jQuery("#wolk_ccNo").val()
    let cardholder = jQuery("#wolk_cardholder").val()
    cc = cc.replaceAll(' ','');
    let cc_last_6 = cc.substr(cc.length - 6);
    var data = new FormData();
   
    jQuery.ajax({
        url: ajax_var.url,
        data: {
            'action':'wolk_submit_error_logs',
            'order_id' : order_id,
            'cc_last_6': cc_last_6,
            'cc_name' : cardholder,
            'type' : values.type,
            'details' : values.details,
            'nonce' : ajax_var.nonce
        },
        method: 'POST',
        dataType : 'json',
        success:function(data) {
            // This outputs the result of the ajax request
            console.log(data);
        },
        error: function(errorThrown){
            console.log(errorThrown);
        }
    }); 
   
}

  function show_form_error(){
    jQuery('#purchase').remove()
    jQuery('.form-error').text(_lang("payment-form-not-available"))
    jQuery(".form-error").css({
        color: "red"
    })
    
  }
  jQuery(document).ready(function(jQuery){
    jQuery("#wolk_ccNo").keyup(()=>{
        jQuery(".card-error").text("")
    })
    jQuery("#wolk_cardholder").keyup(()=>{
        jQuery(".holder-error").text("")
    })
    jQuery("#wolk_month").change(()=>{
        jQuery(".expiry-error").text("")
    })
    jQuery("#wolk_year").change(()=>{
        jQuery(".expiry-error").text("")
    })
    jQuery("#wolk_cvc").keyup(()=>{
        jQuery(".cvc-error").text("")
    })
    jQuery("#request-payment").submit((e)=>{
        e.preventDefault();
        let customer_ip = jQuery("#customer_ip").val()
        let cc = jQuery("#wolk_ccNo").val()
        let cardholder = jQuery("#wolk_cardholder").val()
        let wolk_month = jQuery("#wolk_month").val()
        let wolk_year = jQuery("#wolk_year").val()
        let wolk_cvc = jQuery("#wolk_cvc").val()
        let wolk_first_name = jQuery("#wolk_first_name").val()
        let wolk_last_name = jQuery("#wolk_last_name").val()
        let wolk_email = jQuery("#wolk_email").val()
        let card_type = creditCardType(cc)
        cc = cc.replaceAll(' ','');
        

        if(wolk_first_name == "" || wolk_first_name.length < 3){
            jQuery(".first_name-error").text(_lang("invalid first name."))
            jQuery(".first_name-error").css({
                color: "red"
            })
            jQuery("#wolk_first_name").focus();
        }
        else if(wolk_last_name == "" || wolk_last_name.length < 3){
            jQuery(".last_name-error").text(_lang("invalid last name."))
            jQuery(".last_name-error").css({
                color: "red"
            })
            jQuery("#wolk_last_name").focus();
        }
        else if(card_type == "AMEX" && cc.length < 15){
        
            jQuery(".card-error").text(_lang("invalid card number."))
            jQuery(".card-error").css({
                color: "red"
            })
            jQuery("#wolk_ccNo").focus();
        }
        else if(card_type !== "AMEX" && cc.length < 16){
            jQuery(".card-error").text(_lang("invalid card number."))
            jQuery(".card-error").css({
                color: "red"
            })
            jQuery("#wolk_ccNo").focus();
        }
    
        else if(cardholder == "" || cardholder.length < 3){
            jQuery(".holder-error").text(_lang("invalid card holder."))
            jQuery(".holder-error").css({
                color: "red"
            })
            jQuery("#wolk_cardholder").focus();
        }
        else if(wolk_email == "" || wolk_email.length < 3){
            jQuery(".email-error").text(_lang("invalid email."))
            jQuery(".email-error").css({
                color: "red"
            })
            jQuery("#wolk_email").focus();
        }
        else if(wolk_month == "00" || wolk_year == "00"){
            jQuery(".expiry-error").text(_lang("invalid expiry date."))
            jQuery(".expiry-error").css({
                color: "red"
            })
        }
        else if(wolk_cvc.length <= 2|| wolk_cvc == "" || wolk_cvc == " "){
            jQuery(".cvc-error").text(_lang("invalid cvc."))
            jQuery(".cvc-error").css({
                color: "red"
            })
            jQuery("#wolk_cvc").focus();
        }else{

            const options = {
                cardNumber: cc ,
                cardExpMonth: wolk_month ,
                cardExpYear: wolk_year ,
                currency: currency_code,
                country : country,
                // currency: "CRC",
                // country: 'CR',
                amount: total ,
                firstName: wolk_first_name ,
                lastName: wolk_last_name ,
                email : wolk_email
                //ipaddress : customer_ip

            };

            request_auth(options)
        }

        
    })
    jQuery("#close-modal").click(()=>{
        jQuery("authBox").hide()
        jQuery("#loader").hide()
        jQuery("#responseTitle").html("")
        jQuery("#response").html("")
        jQuery('#close-modal').hide();

        jQuery("#wolk_ccNo").val('')
        jQuery("#wolk_cardholder").val('')
        jQuery("#wolk_month").val('00')
        jQuery("#wolk_year").val('00')
        jQuery("#wolk_cvc").val('')
        jQuery("#wolk_first_name").val('')
        jQuery("#wolk_last_name").val('')
        jQuery("#wolk_email").val('')

        if(threeDSecureInterface){
            threeDSecureInterface.unmount()
        }
        
    })

})

// Auto-rellena el nombre del titular de la tarjeta basándose en el nombre y apellido
jQuery(document).ready(function($) {
    $('#wolk_first_name, #wolk_last_name').on('input', function() {
        let firstName = $('#wolk_first_name').val();
        let lastName = $('#wolk_last_name').val();
        $('#wolk_cardholder').val(firstName + ' ' + lastName);
    });
});