<?php  if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly ?>
<?php get_header(); ?>
<?php

/* Template Name: Payment Process */

require plugin_dir_path(__DIR__).'lang.php';
$years = range(gmdate("Y", strtotime('+10 years')), gmdate("Y", strtotime('-5 years')));

global $post;
global $wpdb;
global $woocommerce;
$order_id = isset($_GET['order']) ? esc_html(sanitize_text_field($_GET['order'])) : '';
$order = wc_get_order( $order_id );
$items = $order->get_items();
$currency_code = $order->get_currency();
$country =  $order->get_billing_country();
$currency_symbol = get_woocommerce_currency_symbol( $currency_code );
$customer_ip = get_customer_ip();

function get_customer_ip() {
    $ipaddress = '';
    if (isset($_SERVER['HTTP_CLIENT_IP'])) {
        $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
        $ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
    } elseif (isset($_SERVER['HTTP_X_FORWARDED'])) {
        $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
    } elseif (isset($_SERVER['HTTP_X_CLUSTER_CLIENT_IP'])) {
        $ipaddress = $_SERVER['HTTP_X_CLUSTER_CLIENT_IP'];
    } elseif (isset($_SERVER['HTTP_FORWARDED_FOR'])) {
        $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
    } elseif (isset($_SERVER['HTTP_FORWARDED'])) {
        $ipaddress = $_SERVER['HTTP_FORWARDED'];
    } elseif (isset($_SERVER['REMOTE_ADDR'])) {
        $ipaddress = $_SERVER['REMOTE_ADDR'];
    } else {
        $ipaddress = 'UNKNOWN';
    }
    return $ipaddress;
}

if($order == false){
    wp_redirect(home_url());
    exit();
}

$Payment_Gateway = new Wolk_Payment_Gateway();
$public_key = $Payment_Gateway->get_option('public_key');
$security_key = $Payment_Gateway->get_option('security_key');
$sys_lang = $Payment_Gateway->get_option('lang');
$brand_color = $Payment_Gateway->get_option('brand_color');
$currency_symbol = $Payment_Gateway->get_option('currency_symbol');
$currency_symbol = get_woocommerce_currency_symbol($currency_symbol);

//$your_gateway->your_setting;
// Get the meta data in an unprotected array
$order_data = $order->get_data();

$ccno = isset($_GET['ccno']) ?  $Payment_Gateway->encrypt_decrypt('decrypt',esc_html(sanitize_text_field($_GET['ccno'])),'order',$order_id) : '';
$exp_m = isset($_GET['exp_m']) ?  $Payment_Gateway->encrypt_decrypt('decrypt',esc_html(sanitize_text_field($_GET['exp_m'])),'order',$order_id) : '';
$exp_y = isset($_GET['exp_y']) ?  $Payment_Gateway->encrypt_decrypt('decrypt',esc_html(sanitize_text_field($_GET['exp_y'])),'order',$order_id) : '';
$cvv = isset($_GET['cvv']) ?  $Payment_Gateway->encrypt_decrypt('decrypt',esc_html(sanitize_text_field($_GET['cvv'])),'order',$order_id) : '';

$first_name = esc_html(sanitize_text_field($order_data['billing']['first_name']));
$last_name = esc_html(sanitize_text_field($order_data['billing']['last_name']));
$total = esc_html(sanitize_text_field($order_data['total']));

?>
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">

<script>
    let public_key =  '<?php echo esc_html($public_key) ?>'
    let security_key = '<?php echo esc_html($security_key) ?>'
    let ccno =  '<?php echo esc_html($ccno) ?>'
    let exp_m =  '<?php echo esc_html($exp_m) ?>'
    let exp_y =  '<?php echo esc_html($exp_y) ?>'
    let cvv =  '<?php echo esc_html($cvv) ?>'
    let total =  '<?php echo esc_html($total) ?>'
    let langu = '<?php echo wp_json_encode($lang,true) ?>' ;
    let order_id = '<?php echo esc_html($order_id) ?>' ;
    let sys_lang = '<?php echo esc_html($sys_lang) ?>';
    let currency_code = '<?php echo esc_html($currency_code) ?>';
    let country = '<?php echo esc_html($country) ?>';
</script>

<div id="wrapper">
	<div id="container">
		<div id="left-col" style="
			background :  <?php echo esc_html($brand_color) ?>
		">
			<div id="left-col-cont">
				<h2><?php echo  esc_html($Payment_Gateway->_lang('Summary')) ?></h2>
                <div class="items-list">
                <?php 
                    foreach ($order->get_items() as $item_id => $item ) {
                        $product = $item->get_product();
                        $thumbnail = $product->get_image(array(60, 60));
                        $product_name   = $item->get_name();
                        $item_quantity  = $item->get_quantity();
                        $item_total     = $item->get_total();
                        ?>
                            <div class="item">
                                <div class="img-col">
                                    <?php echo wp_kses_post($product->get_image(array(60, 60))); ?>
                                </div>
                                <div class="meta-col">
                                    <h3><?php echo esc_html($product_name); ?></h3>
                                    <p class="price">x<?php echo esc_html($item_quantity); ?></p>
									<p class="price"><?php echo wc_price($item_total); ?></p>

                                </div>
                            </div>

                        <?php 
                    
            
                    }
                ?>
                </div>
				<p id="total"><?php echo esc_html($Payment_Gateway->_lang('Total')) ?></p>
<h4 id="total-price"><?php echo wc_price($total); ?></h4>

			</div>
		</div>
		<div id="right-col">
			<h2><?php echo  esc_html($Payment_Gateway->_lang('Payment')) ?></h2>
			<div id="logotype">
				<img id="mastercard" src="<?php echo esc_html($Payment_Gateway->get_custom_logo_url()) ?>" alt="" />
			</div>
			
			<form action="javascript:;" id="request-payment">
				<input type="hidden" id="customer_ip" value="<?php echo esc_html($customer_ip) ?>" >
				<div style="display:inline-flex;gap:10px;width: 100%;">
						<div>
							<label for=""><?php echo  esc_html($Payment_Gateway->_lang('First Name')) ?> <i class="fas fa-user"></i></label>
							<input id="wolk_first_name" type="text" placeholder="First Name" value="<?php echo esc_html($first_name) ?>"/>
							<div class="first_name-error"></div>
						</div>
						<div>
							<label for=""><?php echo  esc_html($Payment_Gateway->_lang('Last Name')) ?> <i class="fas fa-user"></i></label>
							<input id="wolk_last_name" type="text" placeholder="Last Name" value="<?php echo esc_html($last_name) ?>"/>
							<div class="last_name-error"></div>
						</div>
				</div>

				<label for="wolk_ccNo"><?php echo  esc_html($Payment_Gateway->_lang('Card Number')) ?> <i class="fas fa-credit-card"></i></label>
<input type="tel" id="wolk_ccNo" name="wolk_ccNo" placeholder="1234 5678 9012 3456" maxlength="19">
<div class="card-error"></div>

				
				<label for=""><?php echo  esc_html($Payment_Gateway->_lang('Card Holder')) ?> <i class="fas fa-id-card"></i></label>
				<input id="wolk_cardholder" type="text" placeholder="Nombre Apellidos" value="" />
				<div class="holder-error"></div>
				
				<label for=""><?php echo  esc_html($Payment_Gateway->_lang('Email')) ?> <i class="fas fa-envelope"></i></label>
				<input id="wolk_email" type="text" placeholder="correo@email.com" value="" />
				<div class="email-error"></div>
				
				<div class="left">
					<label for=""><?php echo  esc_html($Payment_Gateway->_lang('Expiry Date')) ?> <i class="fas fa-calendar-alt"></i></label>
					<div class="d-flex" style="display:flex;gap:10px" >
						<select name="month" id="wolk_month" onchange="" size="1">
							<option value="00"><?php echo  esc_html($Payment_Gateway->_lang('Month')) ?></option>
							<option value="01"><?php echo  esc_html($Payment_Gateway->_lang('January')) ?></option>
							<option value="02"><?php echo  esc_html($Payment_Gateway->_lang('February')) ?></option>
							<option value="03"><?php echo  esc_html($Payment_Gateway->_lang('March')) ?></option>
							<option value="04"><?php echo  esc_html($Payment_Gateway->_lang('April')) ?></option>
							<option value="05"><?php echo  esc_html($Payment_Gateway->_lang('May')) ?></option>
							<option value="06"><?php echo  esc_html($Payment_Gateway->_lang('June')) ?></option>
							<option value="07"><?php echo  esc_html($Payment_Gateway->_lang('July')) ?></option>
							<option value="08"><?php echo  esc_html($Payment_Gateway->_lang('August')) ?></option>
							<option value="09"><?php echo  esc_html($Payment_Gateway->_lang('September')) ?></option>
							<option value="10"><?php echo  esc_html($Payment_Gateway->_lang('October')) ?></option>
							<option value="11"><?php echo  esc_html($Payment_Gateway->_lang('November')) ?></option>
							<option value="12"><?php echo  esc_html($Payment_Gateway->_lang('December')) ?></option>
							<!-- Resto de opciones... -->
						</select>
						<select name="year" id="wolk_year" onchange="" size="1">
						<option value="00"><?php echo  esc_html($Payment_Gateway->_lang('Year')) ?></option>
						<?php 
							foreach($years as $year){ 
								$value = substr($year, 2);
								?>
								<option value="<?php echo esc_html($value) ?>"><?php echo esc_html($year) ?></option>
							<?php }
						?>
					
						</select>
					</div>
					
					<div class="expiry-error"></div>
				</div>
				
				<div class="right">
					<label id="cvc-label" for="">CVC <i class="fas fa-lock"></i></label>
					<input id="wolk_cvc" class="cvc"  type="number" placeholder="123" maxlength="4" />
					<div class="cvc-error"></div>
				</div>
				<div class="form-error"></div>
				<button type="submit" id="purchase" style="
						background : <?php echo esc_html($brand_color); ?>
					"><i class="fas fa-shopping-cart"></i> <?php echo  esc_html($Payment_Gateway->_lang('Purchase')) ?></button>
			</form>
		</div>
	</div>
</div>

<authBox>
	<modal>
		<div id="detail-content">
			<div id="loader">
				<?php
					include plugin_dir_path(__DIR__).'assets/loader.svg'
				?>
			</div>
			<div>
				<h1 id="responseTitle" style="text-align:center; font-size:3em;margin-top:10px"></h1>
				<p style="text-align:center; font-size:1.5em; margin-top:10px;padding:7px 35px"  id="response"></p>
			</div>
		</div>

		<div class="button-container">
			<button id="close-modal"><?php echo  esc_html($Payment_Gateway->_lang('Close')) ?> </button>
		</div>
	</modal>				
</authBox>

<?php get_footer(); ?>


