<?php
/* @wordpress-plugin
 * Plugin Name: Wolk Payment Gateway
 * Plugin URI: https://wolksoftcr.com/plug-in-payment-gateway
 * Description: <p>Presenting our 3D Secure-based secure payment plugin: A robust solution that ensures the security of your users' transactions. Our plugin fully complies with international payment security protocols, providing you with peace of mind. Installation is simple, and for a limited time, you can get one year of enhanced security for just $75 or two years for $100. Plus, we offer 24/7 support to assist you with any questions or concerns regarding the plugin.</p>
 * Version: 1.5
 * Author: WolkSoftware
 * Author URI: https://wolksoftcr.com/
 * Text Domain: wolk-payment-gateway
 * Domain Path: /languages
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly 
require 'auth/class-wolk-license-auth.php';
  // table name

$active_plugins = apply_filters('active_plugins', get_option('active_plugins'));
if(wolk_payment_is_woocommerce_active()){
	add_filter('woocommerce_payment_gateways', 'wolk_init_wolk_payment_gateway');
	function wolk_init_wolk_payment_gateway( $gateways ){
		$gateways[] = 'Wolk_Payment_Gateway';
		return $gateways;
	}

	add_action('plugins_loaded', 'wolk_include_wolk_payment_gateway');
	function wolk_include_wolk_payment_gateway(){
		require 'class-wolk-payment-gateway.php';
	}

	add_action( 'plugins_loaded', 'wolk_payment_load_plugin_textdomain' );
	function wolk_payment_load_plugin_textdomain() {
	  load_plugin_textdomain( 'wolk-payment-gateway', false, basename( dirname( __FILE__ ) ) . '/languages/' );
	}

	// Hook the custom function to the 'woocommerce_blocks_loaded' action
    add_action( 'woocommerce_blocks_loaded', 'register_order_approval_payment_method_type' );

    /**
     * Custom function to register a payment method type

    */
    function register_order_approval_payment_method_type() {
        // Check if the required class exists
        if ( ! class_exists( 'Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType' ) ) {
            return;
        }

        // Include the custom Blocks Checkout class
        require_once 'class-block.php';

        // Hook the registration function to the 'woocommerce_blocks_payment_method_type_registration' action
        add_action(
            'woocommerce_blocks_payment_method_type_registration',
            function( Automattic\WooCommerce\Blocks\Payments\PaymentMethodRegistry $payment_method_registry ) {
                // Register an instance of Wolk_Payment_Gateway_Blocks
                $payment_method_registry->register( new Wolk_Payment_Gateway_Blocks() );
            }
        );
    }
}
function wolk_enqueue_wolk_custom_admin_script() {
    wp_enqueue_style( 'datatable_style', plugin_dir_url(__FILE__).'/assets/dist/datatables/datatables.css' , false );
	wp_enqueue_script( 'datatables', plugin_dir_url(__FILE__).'/assets/dist/datatables/datatables.min.js', array( 'jquery' ) );
	
	/// Paypal Buttons
	wp_register_script( 'paypal-buttons', '//www.paypal.com/sdk/js?client-id=AWMDsfc9toExRdurz4LZy6T_XIjTLUsWtB2jEy1wvaMTrcHjDcWaXR5t7T9kiT3a5NN1PxQvDHhG4cmf&vault=true&intent=subscription',array(),
    null,
    false );
	wp_enqueue_script('paypal-buttons');
	wp_enqueue_style( 'my_style', plugin_dir_url(__FILE__).'/assets/style.css' , false );

	// wp_localize_script('myplugin-ajax', 'ajax_var', array(
	// 	'url' => admin_url('admin-ajax.php'),
	// 	'nonce' => wp_create_nonce('ajax-nonce')
	// ));
}

add_action( 'admin_enqueue_scripts', 'wolk_enqueue_wolk_custom_admin_script' );

function wolk_enqueue_wolk_custom_script() {
	wp_enqueue_style(
		'payment-proccess-css', // Handle for the stylesheet
		plugin_dir_url(__FILE__).'/templates/payment-proccess.css', // Path to the stylesheet
		array(), // Dependencies (none in this case)
		'1.0.0', // Version number
		'all' // Media type (default is 'all')
	);
	wp_enqueue_script( 'networkmerchants', 'https://secure.networkmerchants.com/js/v1/Gateway.js', array(),'1.0.0','all');
	wp_enqueue_script( 'payment-proccess', plugin_dir_url(__FILE__).'/templates/payment-proccess.js', array('jquery'),'1.0.0','all');
	wp_enqueue_script( 'payment-function', plugin_dir_url(__FILE__).'/assets/function.js', array('jquery'),'1.0.0','all');

	/// AJAX NONCE
	wp_localize_script('payment-proccess', 'ajax_var', array(
		'url' => admin_url('admin-ajax.php'),
		'nonce' => wp_create_nonce('ajax-nonce')
	));
	//wp_enqueue_script( 'sweetalert2',  plugin_dir_url(__FILE__).'/assets/dist/sweetalert2-7.20.0/dist/sweetalert2.all.min.js', array('jquery'),'',true);
}

add_action( 'wp_enqueue_scripts', 'wolk_enqueue_wolk_custom_script' );


// function my_custom_script() {
	
// 	wp_register_script(
// 		'payment-proccess', // name your script so that you can attach other scripts and de-register, etc.
// 		plugin_dir_url(__FILE__).'/templates/payment-proccess.js', // this is the location of your script file
// 		array('jquery'),// this array lists the scripts upon which your script depends
// 		'',
// 		true
// 	);
// 	wp_enqueue_script('payment-proccess');
// }
// do_action('wp_enqueue_scripts', 'my_custom_script');



/**
 * @return bool
 */
function wolk_payment_is_woocommerce_active()
{
	$active_plugins = (array) get_option('active_plugins', array());

	if (is_multisite()) {
		$active_plugins = array_merge($active_plugins, get_site_option('active_sitewide_plugins', array()));
	}

	return in_array('woocommerce/woocommerce.php', $active_plugins) || array_key_exists('woocommerce/woocommerce.php', $active_plugins);
}

add_action( 'before_woocommerce_init', function() {
	if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );

/** Activation hook **/
register_activation_hook(__FILE__, 'wolk_plugin_activation_init');
register_activation_hook(__FILE__, 'wolk_plugin_activation_init_create_table');
function wolk_plugin_activation_init() {   

	$post_tite = 'Wolk Payment Page';
	$payment_post = new WP_Query(
		array(
			'post_type'              => 'page',
			'title'                  => $post_tite
		)
	);
	if(empty( $payment_post->post )){
		$payment_proccess_post = array(
			'post_title'    => wp_strip_all_tags($post_tite),
			'post_content'  => '',
			'post_status'   => 'publish',
			'post_author'   => 1,
			'post_type'     => 'page',
		  );
		// Insert the post into the database
		$page = wp_insert_post( $payment_proccess_post );
		add_option('wolk_wc_payment_page_id',$page,'','yes');
		add_post_meta($page, '_wp_page_template', 'payment-process.php');
	}



}

function wolk_plugin_activation_init_create_table() {   

	global $wpdb;
	$wolk_error_logs_table_name = $wpdb->prefix . 'wolk_error_logs';
	// add error logs table
	$wolk_error_logs_db_version = '1.0.0';
 	$charset_collate = $wpdb->get_charset_collate();
	
	 if($wpdb->get_var( $wpdb->prepare("SHOW TABLES LIKE %s", $wolk_error_logs_table_name)) != $wolk_error_logs_table_name ) 
	 {

		// echo $charset_collate;
		// wp_die();
		   
		$sql = "CREATE TABLE `$wolk_error_logs_table_name` (
					`id` int(11) NOT NULL auto_increment,
					`order_id` varchar(256) NOT NULL,
					`cc_last_6` varchar(15) NOT NULL,
					`cc_name` varchar(60) NOT NULL,
					`details` text NOT NULL,
					`type` varchar(50) NOT NULL,
					`created_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
					UNIQUE KEY id (id)
			) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;";

	   require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	   dbDelta( $sql );
	   add_option( 'wolk_error_logs_db_version', $wolk_error_logs_db_version );
	   wp_die();
	 }

}

function wolk_custom_templates($templates) {

	$templates['payment-process.php'] = 'Payment Process';
	// Add more templates as needed
	return $templates;
}

add_filter('theme_page_templates', 'wolk_custom_templates');


function wolk_assign_custom_template($template) {
	$current_template = get_post_meta(get_the_ID(), '_wp_page_template', true);
	
	if ($current_template === 'payment-process.php') {
		$template = plugin_dir_path(__FILE__) . 'templates/payment-process.php';
	}
	// Add more conditions for other templates

	return $template;
}
add_filter('page_template', 'wolk_assign_custom_template');



function wolk_complete_order() {	
	
	global $woocommerce;
	$Payment_Gateway = new Wolk_Payment_Gateway();

	$order_id = "";
	if ( ! wp_verify_nonce( $_POST['nonce'], 'ajax-nonce' ) ) {
		die ( 'Invalid Nonce!');
	}
	else{
		if(isset($_POST['order_id'])){
			$order_id = esc_html(sanitize_text_field($_POST['order_id']));
		} 
		$order = wc_get_order( $order_id );
		$order_data = $order->get_data();
		$order->update_status($Payment_Gateway->get_order_status(), __( 'Awaiting payment', 'wolk-payment-gateway' ));
		// Reduce stock levels
		wc_reduce_stock_levels( $order_id );
		if(!empty($_POST[$Payment_Gateway->get_id().'-admin-note'])){
			if(isset($_POST[$Payment_Gateway->get_id().'-admin-note']) && trim($_POST[$Payment_Gateway->get_id().'-admin-note']) !=''){
				$order->add_order_note(esc_html(sanitize_text_field($_POST[ $Payment_Gateway->get_id().'-admin-note'])));
			}
		}
		
		// Remove cart
		$woocommerce->cart->empty_cart();
		// Return thankyou redirect
		echo wp_json_encode([
			'result' => 'success',
			'redirect' => $Payment_Gateway->get_return_url( $order )
		]);
		exit();
	}
}
add_action('wp_ajax_wolk_complete_order', 'wolk_complete_order' ); // executed when logged in
add_action('wp_ajax_nopriv_wolk_complete_order', 'wolk_complete_order' ); // executed when logged out




function wolk_submit_payment_request() {
	//'https://secure.networkmerchants.com/api/transact.php'


	$ipaddress = '';
    if (isset($_SERVER['HTTP_CLIENT_IP'])) {
        $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
        $ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
    } elseif (isset($_SERVER['HTTP_X_FORWARDED'])) {
        $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
    } elseif (isset($_SERVER['HTTP_X_CLUSTER_CLIENT_IP'])) {
        $ipaddress = $_SERVER['HTTP_X_CLUSTER_CLIENT_IP'];
    } elseif (isset($_SERVER['HTTP_FORWARDED_FOR'])) {
        $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
    } elseif (isset($_SERVER['HTTP_FORWARDED'])) {
        $ipaddress = $_SERVER['HTTP_FORWARDED'];
    } elseif (isset($_SERVER['REMOTE_ADDR'])) {
        $ipaddress = $_SERVER['REMOTE_ADDR'];
    } else {
        $ipaddress = 'UNKNOWN';
    }

	if ( ! wp_verify_nonce( $_POST['nonce'], 'ajax-nonce' ) ) {
		die ( 'Invalid Nonce!');
	}
	else{
	
		$query = "";
		// the api which we are using in it, not sending the specified variables. so we need to proccess the whole post 
		$d = $_POST;

		// echo json_encode($_POST);
		// die;
		$d['ipaddress'] = $ipaddress;
		unset($d['action']);
		if($d['xid'] == 'null'){
			$d['xid'] = null;
		}

		foreach($d as $key => $row){
			if($row == null){
				$query.= $key.'='.($row).'&';
			}
			else{
				$query.= $key.'='.urlencode($row).'&';
			}
			
		}

		$url = "https://secure.nmi.com/api/transact.php";
		$args = [
			'sslverify' => false,
			'body' => $query,
		];
		// $query = substr($query,0,-1);
		// $ch = curl_init();
		// curl_setopt($ch, CURLOPT_URL, "https://secure.nmi.com/api/transact.php");
		// curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 30);
		// curl_setopt($ch, CURLOPT_TIMEOUT, 30);
		// curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		// curl_setopt($ch, CURLOPT_HEADER, 0);
		// curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

		// curl_setopt($ch, CURLOPT_POSTFIELDS, $query);
		// curl_setopt($ch, CURLOPT_POST, 1);

		// if (!($data = curl_exec($ch))) {
		//     return ERROR;
		// }
		// curl_close($ch);
		// unset($ch);

		$response = wp_remote_post('https://secure.nmi.com/api/transact.php', array(
			'method' => 'POST',
			'timeout' => 30,
			'body' => $query,
		));
		//$result = wp_remote_post($url, $args);
			
		$body = wp_remote_retrieve_body( $response );
		echo esc_html($body);
		exit();
	}
	
}
add_action('wp_ajax_wolk_submit_payment_request', 'wolk_submit_payment_request' ); // executed when logged in
add_action('wp_ajax_nopriv_wolk_submit_payment_request', 'wolk_submit_payment_request' ); // executed when logged out



add_action( 'wp_ajax_getpostsfordatatables', 'wolk_ajax_getpostsfordatatables' );
add_action( 'wp_ajax_nopriv_getpostsfordatatables', 'wolk_ajax_getpostsfordatatables' );
function wolk_ajax_getpostsfordatatables() {
  global $wpdb;
  $wolk_error_logs_table_name = sprintf( '%s'. 'wolk_error_logs',$wpdb->prefix);

  $start = isset( $_GET['start'] ) ? absint( $_GET['start'] ) : 1;
	
  $escaped_table_name = esc_sql($wolk_error_logs_table_name);
  $total = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM {$escaped_table_name}"));
	
  $limit = isset( $_GET['length'] ) ? absint( $_GET['length'] ) : 1;
  $search_col =  ['order_id','cc_last_6','cc_name','type'];
  $search = esc_attr( trim( esc_html(sanitize_text_field($_GET['search']['value'] ) )));
  $search_sql = esc_html(""); 
  if($search != ""){
	// foreach($search_col as $key => $s){
	// 	if($key == 0){
	// 		$search_sql .= sprintf(" where  %i LIKE '%$search%' " , $s);
	// 		//$search_sql .= sprintf(" where  %i LIKE '%$search%' " , $s);
	// 	}else{
	// 		$search_sql.= sprintf(" OR %i LIKE '%$search%' ", $s);
	// 	}
		
	//   }

	 $search_term = '%' . $wpdb->esc_like($search) . '%';
	 $search_sql .= $wpdb->prepare(" WHERE order_id LIKE %s ", $search_term);
	 $search_sql .= $wpdb->prepare(" or cc_last_6 LIKE %s ", $search_term);
	 $search_sql .= $wpdb->prepare(" or cc_name LIKE %s ", $search_term);
	 $search_sql .= $wpdb->prepare(" or type LIKE %s ", $search_term);
	  
	  // Escape the table name
	$escaped_table_name = esc_sql($wolk_error_logs_table_name);
	
	  
	 
	  
	   $result = $wpdb->get_results($wpdb->prepare(
		"SELECT * FROM {$escaped_table_name} {$search_sql} ORDER BY created_time DESC LIMIT %d, %d",
			$start, $limit
		));
  }
  else{
	  
	    $escaped_table_name = esc_sql($wolk_error_logs_table_name);

		// Prepare the SQL query without using %i
		$result = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT * FROM {$escaped_table_name} ORDER BY created_time DESC LIMIT %d, %d",
				$start, $limit
			)
		);
  }
  
  //$qry= sprintf("select * from %i %s order by created_time desc LIMIT %s , %s ", array($wolk_error_logs_table_name , $search_sql ,$start ,$limit));
  


  //create empty array and loop through results, populating array
  $data = array();
  foreach ($result as $row ) {
	$sub_data = array();  


	
	$details=  json_decode($row->details);
	if(!is_array($details) && ! is_object($details)){
		$details = [];
	}
	

	$details_data= '';
	foreach($details as $d_key => $d ){
		$details_data .=  "<strong>".$d_key."</strong> : ".$d."</br>";
	}

	$sub_data[] = $row->order_id;      
	$sub_data[] = $row->cc_last_6;      
	$sub_data[] = $row->cc_name;      
	$sub_data[] = $details_data;      
	$sub_data[] = $row->type;      
	$sub_data[] = $row->created_time;      
	$data[] = $sub_data; 
}

  
  //return the result to the ajax request and die
  echo wp_json_encode(array(
	"draw" =>  (isset($_GET["draw"]) ? esc_html(sanitize_text_field($_GET["draw"])) : 0),  
	'data' => $data,
	"recordsTotal"      =>  intval($total),
	"recordsFiltered"   =>  intval(count($result)),
));
  wp_die();
}


add_action('wp_ajax_wolk_submit_error_logs', 'wolk_submit_error_logs' );
add_action('wp_ajax_nopriv_wolk_submit_error_logs', 'wolk_submit_error_logs' );
function wolk_submit_error_logs() {
	
  global $wpdb;
  $wolk_error_logs_table_name = $wpdb->prefix . 'wolk_error_logs';
  //some basic query arguments
  if ( ! wp_verify_nonce( $_POST['nonce'], 'ajax-nonce' ) ) {
		die ( 'Invalid Nonce!');
  }
  else{
	$data=array(
		'order_id' => esc_html(sanitize_text_field($_POST['order_id'])), 
		'cc_last_6' => esc_html(sanitize_text_field($_POST['cc_last_6'])), 
		'cc_name' => esc_html(sanitize_text_field($_POST['cc_name'])),
		'details' => wp_json_encode(($_POST['details'])), 
		'type' => esc_html(sanitize_text_field($_POST['type'])), 
	  );
		
	
	  $wpdb->insert( $wolk_error_logs_table_name, $data);
	  //return the result to the ajax request and die
	  echo wp_json_encode(array('status' => 200 ));
	  wp_die();
  }
  
}



/* datatables css and js */



